==> medium-editor-markdown-2.5.0.tgz: package/src/medium-editor-md.js <==
"use strict";

/**
 * MeMarkdown
 * Creates a new instance of `MeMarkdown`.
 *
 * @name MeMarkdown
 * @function
 * @param {Object} options An object containing the following fields:
 *
 *  - `events` (Array): An array with the events when the markdown code will be generated (default: `["input", "change"]`).
 *  - `callback` (Function): The callback function. If the second argument is a function, then it has greater priority.
 *  - `toMarkdownOptions` (Object): Options to pass to the markdown converter code.
 *  - `ignorebuiltinconverters` (Boolean): If `true`, the default converters passed to `toMarkdown` will be ignored.
 *
 * @param {Function} callback The callback function that is called with the markdown code (first argument).
 */

var toMarkdown = require('to-markdown');

module.exports = function (options, callback) {

    if (typeof options === "function") {
        callback = options;
        options = {};
    }

    // Defaults
    options = Object(options);
    options.events = options.events || ["input", "change"];
    callback = callback || options.callback || function () {};

    var toMarkdownOptions = options.toMarkdownOptions = Object(options.toMarkdownOptions);
    toMarkdownOptions.converters = toMarkdownOptions.converters || [];

    if (!options.ignoreBuiltInConverters) {
        toMarkdownOptions.converters.push({
            filter: function (node) {
                return node.nodeName === "DIV" && !node.attributes.length;
            }
          , replacement: function (content) {
                return content;
            }
        });
    }

    function normalizeList ($elm) {
        var $children = $elm.children;
        for (var i = 0; i < $children.length; ++i) {
            var $cChild = $children[i];
            var $br = $cChild.querySelector("br");
            $br && $br.remove();
            !$cChild.innerHTML.trim() && $cChild.remove();
            var $prevChild = $children[i - 1];
            if (/^UL|OL$/.test($cChild.tagName)) {
                try {
                    $prevChild.appendChild($cChild);
                } catch (e) { console.warn(e); }
                normalizeList($cChild);
            }
        }
    }

    // Called by medium-editor during init
    this.init = function () {

        // If this instance of medium-editor doesn't have any elements, there's nothing for us to do
        if (!this.base.elements || !this.base.elements.length) {
            return;
        }

        // Element(s) that this instance of medium-editor is attached to is/are stored in .elements
        this.element = this.base.elements[0];

        var handler = function () {
            var $clone = this.element.cloneNode(true);
            var $lists = $clone.querySelectorAll("ul, ol");
            for (var i = 0; i < $lists.length; ++i) {
                normalizeList($lists[i]);
            }

            callback(toMarkdown($clone.innerHTML, options.toMarkdownOptions).split("\n").map(function (c) {
                return c.trimRight();
            }).join("\n").trimRight());
        }.bind(this);

        options.events.forEach(function (c) {
            this.element.addEventListener(c, handler);
        }.bind(this));

        handler();
    };
};

==> medium-editor-markdown-3.0.0.tgz: package/src/medium-editor-md.js <==
"use strict";

/**
 * MeMarkdown
 * Creates a new instance of `MeMarkdown`.
 *
 * @name MeMarkdown
 * @function
 * @param {Object} options An object containing the following fields:
 *
 *  - `events` (Array): An array with the events when the markdown code will be generated (default: `["input", "change"]`).
 *  - `callback` (Function): The callback function. If the second argument is a function, then it has greater priority.
 *  - `toTurndownOptions` (Object): Options to pass to the markdown converter code.
 *  - `ignoreBuiltinConverters` (Boolean): If `true`, the default converters passed to `toMarkdown` will be ignored.
 *
 * @param {Function} callback The callback function that is called with the markdown code (first argument).
 */

var toMarkdown = require('turndown');

module.exports = function (options, callback) {

    if (typeof options === "function") {
        callback = options;
        options = {};
    }

    // Defaults
    options = Object(options);
    options.events = options.events || ["input", "change"];
    callback = callback || options.callback || function () {};

    var toTurndownOptions = options.toTurndownOptions = Object(options.toTurndownOptions);
    toTurndownOptions.converters = toTurndownOptions.converters || [];

    if (!options.ignoreBuiltinConverters) {
        toTurndownOptions.converters.push({
            filter: function (node) {
                return node.nodeName === "DIV" && !node.attributes.length;
            }
          , replacement: function (content) {
                return content;
            }
        });
    }

    function normalizeList ($elm) {
        var $children = $elm.children;
        for (var i = 0; i < $children.length; ++i) {
            var $cChild = $children[i];
            var $br = $cChild.querySelector("br");
            $br && $br.remove();
            !$cChild.innerHTML.trim() && $cChild.remove();
            var $prevChild = $children[i - 1];
            if (/^UL|OL$/.test($cChild.tagName)) {
                try {
                    $prevChild.appendChild($cChild);
                } catch (e) { console.warn(e); }
                normalizeList($cChild);
            }
        }
    }

    // Called by medium-editor during init
    this.init = function () {

        // If this instance of medium-editor doesn't have any elements, there's nothing for us to do
        if (!this.base.elements || !this.base.elements.length) {
            return;
        }

        // Element(s) that this instance of medium-editor is attached to is/are stored in .elements
        this.element = this.base.elements[0];

        // String.prototype.trimRight is non-standard, this should have the same effect
        var rightWhitespace = /[\x09\x0A\x0B\x0C\x0D\x20\xA0\u1680\u180E\u2000\u2001\u2002\u2003\u2004\u2005\u2006\u2007\u2008\u2009\u200A\u202F\u205F\u3000\u2028\u2029\uFEFF]*$/;

        var handler = function () {
            var $clone = this.element.cloneNode(true);
            var $lists = $clone.querySelectorAll("ul, ol");
            for (var i = 0; i < $lists.length; ++i) {
                normalizeList($lists[i]);
            }

            callback( new TurndownService(options.toTurndownOptions).turndown($clone.innerHTML).split("\n").map(function (c) {
                return c.replace(rightWhitespace, '');
            }).join("\n").replace(rightWhitespace, ''));
        }.bind(this);

        options.events.forEach(function (c) {
            this.element.addEventListener(c, handler);
        }.bind(this));

        handler();
    };
};
